unpack_traces

Function unpack_traces 

pub fn unpack_traces<T>(events: &Vec<RBEvent>) -> Vec<Vec<Vec<T>>>
where T: Float + NumAssign + NumCast + Copy,
Get the traces for a set of RBEvents

This will return a cube of The sice of this cube will be fixed in two dimensions, but not the third

The rationale of this is to be able to quickly calculate means over all channels.

Shape [ch:9][nevents][adc_bin:1024]

Args:

events - events to get the traces from